@@ -17,18 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __GPM_MANAGER_H
 #define __GPM_MANAGER_H
 
 #include <glib-object.h>
-#include <dbus/dbus-glib.h>
-
-#define	GPM_DBUS_SERVICE		"org.freedesktop.PowerManagement"
-#define	GPM_DBUS_PATH			"/org/freedesktop/PowerManagement"
-#define	GPM_DBUS_INTERFACE		"org.freedesktop.PowerManagement"
 
 G_BEGIN_DECLS
 
@@ -61,7 +56,6 @@ typedef enum
 	GPM_MANAGER_ERROR_LAST
 } GpmManagerError;
 
-
 GQuark		 gpm_manager_error_quark		(void);
 GType		 gpm_manager_error_get_type		(void);
 GType		 gpm_manager_get_type		  	(void);
@@ -77,9 +71,6 @@ gboolean	 gpm_manager_can_suspend		(GpmManager	*manager,
 gboolean	 gpm_manager_can_hibernate		(GpmManager	*manager,
 							 gboolean	*can_hibernate,
 							 GError		**error);
-gboolean	 gpm_manager_get_preferences_options	(GpmManager	*manager,
-							 gint		*capability,
-							 GError		**error);
 
 G_END_DECLS
 
